GeminiTranslatorAgent class
- Inheritance
-
- Object
- TransalatorAgent
- GeminiTranslatorAgent
Constructors
- GeminiTranslatorAgent({String model = 'gemini-3.5-flash', required String geminiApiKey})
Properties
- geminiApiKey → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- model → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited